@@ -175,15 +175,16 @@ def test_fhd_antenna_pos(fhd_data):
     )
 
     assert fhd_data._antenna_names == mwa_corr_obj._antenna_names
-    assert fhd_data._antenna_numbers == mwa_corr_obj._antenna_numbers
     assert fhd_data._antenna_positions == mwa_corr_obj._antenna_positions
 
     cotter_file = os.path.join(DATA_PATH, "1061316296.uvfits")
     cotter_obj = UVData()
     cotter_obj.read(cotter_file)
 
+    # don't test antenna_numbers, they will not match.
+    # mwa_corr_fits now uses antenna_numbers that correspond to antenna_names
+    # instead of following the cotter convention of using 0-127.
     assert fhd_data._antenna_names == cotter_obj._antenna_names
-    assert fhd_data._antenna_numbers == cotter_obj._antenna_numbers
     assert fhd_data._antenna_positions == cotter_obj._antenna_positions
 
     assert mwa_corr_obj._antenna_positions == cotter_obj._antenna_positions
